@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
 """
 user_tasks Django application initialization.
 """
 
-from __future__ import absolute_import, unicode_literals
-
 from django.apps import AppConfig
 
 
