@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
 """
 Custom exception classes.
 """
 
-from __future__ import absolute_import, unicode_literals
-
 
 class TaskCanceledException(RuntimeError):
     """
