@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
 """
 URLs for user_tasks.
 """
-from __future__ import absolute_import, unicode_literals
 
 from rest_framework.routers import SimpleRouter
 
